.. _pecan_core:

:mod:`pecan.core` -- Pecan Core
===============================

The :mod:`pecan.core` module is the base module for creating and extending
Pecan. The core logic for processing HTTP requests and responses lives
here.

.. automodule:: pecan.core
  :members:
  :show-inheritance: